- data_df
(mandatory)
Data frame (object of class "data.frame") that contains the time series data to be reconciled. It must minimally
contain variables corresponding to the component series and cross-sectional control totals specified in the
metadata data frame (argument metadata_df). If more than one observation (period) is provided, the sum of
the provided component series values will also be preserved as part of implicit temporal constraints.
- metadata_df
(mandatory)
Data frame (object of class "data.frame") that describes the cross-sectional aggregation constraints
(additivity rules) for the raking problem. Two character variables must be included in the metadata data frame:
series and total1. Two variables are optional: total2 (character) and alterAnnual (numeric). The values
of variable series represent the variable names of the component series in the input time series data frame
(argument data_df). Similarly, the values of variables total1 and total2 represent the variable names of
the 1st and 2nd dimension cross-sectional control totals in the input time series data
frame. Variable alterAnnual contains the alterability coefficient for the temporal constraint associated to
each component series. When specified, the latter will override the default alterability coefficient specified
with argument alterAnnual.
- alterability_df
(optional)
Data frame (object of class "data.frame"), or NULL, that contains the alterability coefficients variables.
They must correspond to a component series or a cross-sectional control total, that is, a variable with the same
name must exist in the input time series data frame (argument data_df). The values of these alterability
coefficients will override the default alterability coefficients specified with arguments alterSeries,
alterTotal1 and alterTotal2. When the input time series data frame contains several observations and the
alterability coefficients data frame contains only one, the alterability coefficients are used (repeated) for
all observations of the input time series data frame. Alternatively, the alterability coefficients data frame
may contain as many observations as the input time series data frame.
Default value is alterability_df = NULL (default alterability coefficients).
- alterSeries
(optional)
Nonnegative real number specifying the default alterability coefficient for the component series values. It
will apply to component series for which alterability coefficients have not already been specified in the
alterability coefficients data frame (argument alterability_df).
Default value is alterSeries = 1.0 (nonbinding component series values).
- alterTotal1
(optional)
Nonnegative real number specifying the default alterability coefficient for the 1st dimension
cross-sectional control totals. It will apply to cross-sectional control totals for which alterability
coefficients have not already been specified in the alterability coefficients data frame (argument
alterability_df).
Default value is alterTotal1 = 0.0 (binding 1st dimension cross-sectional control totals)
- alterTotal2
(optional)
Nonnegative real number specifying the default alterability coefficient for the 2nd dimension
cross-sectional control totals. It will apply to cross-sectional control totals for which alterability
coefficients have not already been specified in the alterability coefficients data frame (argument
alterability_df).
Default value is alterTotal2 = 0.0 (binding 2nd dimension cross-sectional control totals).
- alterAnnual
(optional)
Nonnegative real number specifying the default alterability coefficient for the component series temporal
constraints (e.g., annual totals). It will apply to component series for which alterability coefficients
have not already been specified in the metadata data frame (argument metadata_df).
Default value is alterAnnual = 0.0 (binding temporal control totals).
- tolV, tolP
(optional)
Nonnegative real number, or NA, specifying the tolerance, in absolute value or percentage, to be used
when performing the ultimate test in the case of binding totals (alterability coefficient of \(0.0\)
for temporal or cross-sectional control totals). The test compares the input binding control totals with
the ones calculated from the reconciled (output) component series. Arguments tolV and tolP cannot be both
specified together (one must be specified while the other must be NA).
Example: to set a tolerance of 10 units, specify tolV = 10, tolP = NA; to set a tolerance of 1%,
specify tolV = NA, tolP = 0.01.
Default values are tolV = 0.001 and tolP = NA.
- warnNegResult
(optional)
Logical argument specifying whether a warning message is generated when a negative value created by the
function in the reconciled (output) series is smaller than the threshold specified by argument tolN.
Default value is warnNegResult = TRUE.
- tolN
(optional)
Negative real number specifying the threshold for the identification of negative values. A value is
considered negative when it is smaller than this threshold.
Default value is tolN = -0.001.
- id
(optional)
String vector (minimum length of 1), or NULL, specifying the name of additional variables to be transferred
from the input time series data frame (argument data_df) to the output time series data frame, the
object returned by the function (see section Value). By default, the output series data frame only contains
the variables listed in the metadata data frame (argument metadata_df).
Default value is id = NULL.
- verbose
(optional)
Logical argument specifying whether information on intermediate steps with execution time (real time,
not CPU time) should be displayed. Note that specifying argument quiet = TRUE would nullify argument
verbose.
Default value is verbose = FALSE.
- Vmat_option
(optional)
Specification of the option for the variance matrices (\(V_e\) and \(V_\epsilon\); see section Details):
| Value | Description |
1 | Use vectors \(x\) and \(g\) in the variance matrices. |
2 | Use vectors \(|x|\) and \(|g|\) in the variance matrices. |
See Ferland (2016) and subsection Arguments Vmat_option and warnNegInput in section Details for
more information.
Default value is Vmat_option = 1.
- warnNegInput
(optional)
Logical argument specifying whether a warning message is generated when a negative value smaller than
the threshold specified by argument tolN is found in the input time series data frame (argument data_df).
Default value is warnNegInput = TRUE.
- quiet
(optional)
Logical argument specifying whether or not to display only essential information such as warnings and errors.
Specifying quiet = TRUE would also nullify argument verbose and is equivalent to wrapping your
tsraking() call with suppressMessages().
Default value is quiet = FALSE.